# Changelog — free/core/settings

## 0.1.41 — Automated patch release triggered by content hash change (2026-02-14)

- chore: Automated patch release triggered by content hash change

## 0.1.40 — Automated patch release triggered by content hash change (2026-02-14)

- chore: Automated patch release triggered by content hash change

## 0.1.39 — Automated patch release triggered by content hash change (2026-02-14)

- chore: Automated patch release triggered by content hash change

## 0.1.38 — Automated patch release triggered by content hash change (2026-02-14)

- chore: Automated patch release triggered by content hash change

## 0.1.37 — Automated patch release triggered by content hash change (2026-02-14)

- chore: Automated patch release triggered by content hash change

## 0.1.36 — Automated patch release triggered by content hash change (2026-02-14)

- chore: Automated patch release triggered by content hash change

## 0.1.35 — Automated patch release triggered by content hash change (2026-02-12)

- chore: Automated patch release triggered by content hash change

## 0.1.34 — Automated patch release triggered by content hash change (2026-02-12)

- chore: Automated patch release triggered by content hash change

## 0.1.33 — Automated patch release triggered by content hash change (2026-02-11)

- chore: Automated patch release triggered by content hash change

## 0.1.32 — Automated patch release triggered by content hash change (2026-01-04)

- chore: Automated patch release triggered by content hash change

## 0.1.31 — Automated patch release triggered by content hash change (2025-12-31)

- chore: Automated patch release triggered by content hash change

## 0.1.30 — Automated patch release triggered by content hash change (2025-12-30)

- chore: Automated patch release triggered by content hash change

## 0.1.29 — Automated patch release triggered by content hash change (2025-12-28)

- chore: Automated patch release triggered by content hash change

## 0.1.28 — Automated patch release triggered by content hash change (2025-12-26)

- chore: Automated patch release triggered by content hash change

## 0.1.27 — Automated patch release triggered by content hash change (2025-12-25)

- chore: Automated patch release triggered by content hash change

## 0.1.26 — Automated patch release triggered by content hash change (2025-12-25)

- chore: Automated patch release triggered by content hash change

## 0.1.25 — Automated patch release triggered by content hash change (2025-12-25)

- chore: Automated patch release triggered by content hash change

## 0.1.24 — Automated patch release triggered by content hash change (2025-12-25)

- chore: Automated patch release triggered by content hash change

## 0.1.23 — Automated patch release triggered by content hash change (2025-12-23)

- chore: Automated patch release triggered by content hash change

## 0.1.22 — Automated patch release triggered by content hash change (2025-12-23)

- chore: Automated patch release triggered by content hash change

## 0.1.21 — Automated patch release triggered by content hash change (2025-12-22)

- chore: Automated patch release triggered by content hash change

## 0.1.20 — Automated patch release triggered by content hash change (2025-12-22)

- chore: Automated patch release triggered by content hash change

## 0.1.19 — Automated patch release triggered by content hash change (2025-12-22)

- chore: Automated patch release triggered by content hash change

## 0.1.18 — Automated patch release triggered by content hash change (2025-12-17)

- chore: Automated patch release triggered by content hash change

## 0.1.17 — Automated patch release triggered by content hash change (2025-12-16)

- chore: Automated patch release triggered by content hash change

## 0.1.16 — Automated patch release triggered by content hash change (2025-12-16)

- chore: Automated patch release triggered by content hash change

## 0.1.15 — Automated patch release triggered by content hash change (2025-12-15)

- chore: Automated patch release triggered by content hash change

## 0.1.14 — Automated patch release triggered by content hash change (2025-12-15)

- chore: Automated patch release triggered by content hash change

## 0.1.13 — Automated patch release triggered by content hash change (2025-12-15)

- chore: Automated patch release triggered by content hash change

## 0.1.12 — Automated patch release triggered by content hash change (2025-12-14)

- chore: Automated patch release triggered by content hash change

## 0.1.11 — Automated patch release triggered by content hash change (2025-12-14)

- chore: Automated patch release triggered by content hash change

## 0.1.10 — Automated patch release triggered by content hash change (2025-12-14)

- chore: Automated patch release triggered by content hash change

## 0.1.9 — Automated patch release triggered by content hash change (2025-12-14)

- chore: Automated patch release triggered by content hash change

## 0.1.8 — Automated patch release triggered by content hash change (2025-12-14)

- chore: Automated patch release triggered by content hash change

## 0.1.7 — Automated patch release triggered by content hash change (2025-12-14)

- chore: Automated patch release triggered by content hash change

## 0.1.6 — Automated patch release triggered by content hash change (2025-12-12)

- chore: Automated patch release triggered by content hash change

## 0.1.5 — Automated patch release triggered by content hash change (2025-12-11)

- chore: Automated patch release triggered by content hash change

## 0.1.4 — Automated patch release triggered by content hash change (2025-12-09)

- chore: Automated patch release triggered by content hash change

## 0.1.3 — Automated patch release triggered by content hash change (2025-12-09)

- chore: Automated patch release triggered by content hash change

## 0.1.2 — Automated patch release triggered by content hash change (2025-12-09)

- chore: Automated patch release triggered by content hash change

## 0.1.1 — Automated patch release triggered by content hash change (2025-12-04)

- chore: Automated patch release triggered by content hash change

## 0.1.0 — Initial baseline (2025-12-04)

- Initial public baseline.
